@@ -11,8 +11,8 @@ print.Diffepoce <- function(x, digits = 3, ...)
 # 		}
 		out <- cbind(x$pred.times,x$DEPOCE,x$TIinf,x$TIsup)
 		rownames(out) <- rep(" ", length(out[,1]))
-		if (x$new.data) colnames(out) <- c("pred.times","Diff MPL","95%TIinf","95%TIsup")
-		else colnames(out) <- c("pred.times","Diff CVPL","95%TIinf","95%TIsup")
+		if (x$new.data) colnames(out) <- c("pred.times","Diff MPOL","95%TIinf","95%TIsup")
+		else colnames(out) <- c("pred.times","Diff CVPOL","95%TIinf","95%TIsup")
 		print(out)
 	}
 }
